@@ -1,15 +1,32 @@
 use strict;
 use warnings;
 package Dist::Zilla::App::Command::build;
-{
-  $Dist::Zilla::App::Command::build::VERSION = '5.008';
-}
 # ABSTRACT: build your dist
+$Dist::Zilla::App::Command::build::VERSION = '5.043';
 use Dist::Zilla::App -command;
 
+#pod =head1 SYNOPSIS
+#pod
+#pod   dzil build [ --trial ] [ --tgz | --no-tgz ] [ --in /path/to/build/dir ]
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod This command is a very thin layer over the Dist::Zilla C<build> method, which
+#pod does all the things required to build your distribution.  By default, it will
+#pod also archive your distribution and leave you with a complete, ready-to-release
+#pod distribution tarball.
+#pod
+#pod =cut
 
 sub abstract { 'build your dist' }
 
+#pod =head1 EXAMPLE
+#pod
+#pod   $ dzil build
+#pod   $ dzil build --no-tgz
+#pod   $ dzil build --in /path/to/build/dir
+#pod
+#pod =cut
 
 sub opt_spec {
   [ 'trial'  => 'build a trial release that PAUSE will not index'      ],
@@ -17,6 +34,25 @@ sub opt_spec {
   [ 'in=s'   => 'the directory in which to build the distribution'     ]
 }
 
+#pod =head1 OPTIONS
+#pod
+#pod =head2 --trial
+#pod
+#pod This will build a trial distribution.  Among other things, it will generally
+#pod mean that the built tarball's basename ends in F<-TRIAL>.
+#pod
+#pod =head2 --tgz | --no-tgz
+#pod
+#pod Builds a .tar.gz in your project directory after building the distribution.
+#pod
+#pod --tgz behaviour is by default, use --no-tgz to disable building an archive.
+#pod
+#pod =head2 --in
+#pod
+#pod Specifies the directory into which the distribution should be built.  If
+#pod necessary, the directory will be created.  An archive will not be created.
+#pod
+#pod =cut
 
 sub execute {
   my ($self, $opt, $args) = @_;
@@ -25,10 +61,17 @@ sub execute {
     $self->zilla->build_in($opt->in);
   } else {
     my $method = $opt->tgz ? 'build_archive' : 'build';
-    my $zilla  = $self->zilla;
-    $zilla->is_trial(1) if $opt->trial;
+    my $zilla;
+    {
+      # isolate changes to RELEASE_STATUS to zilla construction
+      local $ENV{RELEASE_STATUS} = $ENV{RELEASE_STATUS};
+      $ENV{RELEASE_STATUS} = 'testing' if $opt->trial;
+      $zilla  = $self->zilla;
+    }
     $zilla->$method;
   }
+
+  $self->zilla->log('built in ' . $self->zilla->built_in);
 }
 
 1;
@@ -45,7 +88,7 @@ Dist::Zilla::App::Command::build - build your dist
 
 =head1 VERSION
 
-version 5.008
+version 5.043
 
 =head1 SYNOPSIS
 
@@ -88,7 +131,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
