@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Dist::Zilla::App::Command::listdeps;
 # ABSTRACT: print your distribution's prerequisites
-$Dist::Zilla::App::Command::listdeps::VERSION = '5.020';
+$Dist::Zilla::App::Command::listdeps::VERSION = '5.043';
 use Dist::Zilla::App -command;
 
 #pod =head1 SYNOPSIS
@@ -18,7 +18,7 @@ use Dist::Zilla::App -command;
 #pod
 #pod =head1 OPTIONS
 #pod
-#pod =head2 --author
+#pod =head2 --author (or --develop)
 #pod
 #pod Include author dependencies (those listed under C<develop_requires>).
 #pod
@@ -48,10 +48,11 @@ use Try::Tiny;
 sub abstract { "print your distribution's prerequisites" }
 
 sub opt_spec {
-  [ 'author', 'include author dependencies' ],
+  [ 'develop|author', 'include author/develop dependencies' ],
   [ 'missing', 'list only the missing dependencies' ],
   [ 'versions', 'include required version numbers in listing' ],
   [ 'json', 'list dependencies by phase, in JSON format' ],
+  [ 'omit-core=s', 'Omit dependencies that are shipped with the specified version of perl' ],
 }
 
 sub prereqs {
@@ -67,10 +68,31 @@ sub prereqs {
   my $prereqs = $zilla->prereqs;
 }
 
+my @phases = qw/configure build test runtime develop/;
+my @relationships = qw/requires recommends suggests/;
+
+sub filter_core {
+  my ($prereqs, $core_version) = @_;
+  $core_version = sprintf '%7.6f', $core_version if $core_version >= 5.010;
+  $prereqs = $prereqs->clone if $prereqs->is_finalized;
+  require Module::CoreList;
+  for my $phase (@phases) {
+    for my $relation (@relationships) {
+      my $req = $prereqs->requirements_for($phase, $relation);
+      for my $module ($req->required_modules) {
+        next if not exists $Module::CoreList::version{$core_version}{$module};
+        $req->clear_requirement($module) if $req->accepts_module($module, $Module::CoreList::version{$core_version}{$module});
+      }
+    }
+  }
+  return $prereqs;
+}
+
 sub extract_dependencies {
-  my ($self, $zilla, $phases, $missing) = @_;
+  my ($self, $zilla, $phases, $missing, $omit_core) = @_;
 
   my $prereqs = $self->prereqs($zilla);
+  $prereqs = filter_core($prereqs, $omit_core) if $omit_core;
 
   require CPAN::Meta::Requirements;
   my $req = CPAN::Meta::Requirements->new;
@@ -108,18 +130,20 @@ sub execute {
   $self->app->chrome->logger->mute;
 
   my @phases = qw(build test configure runtime);
-  push @phases, 'develop' if $opt->author;
+  push @phases, 'develop' if $opt->develop;
 
+  my $omit_core = $opt->omit_core;
   if($opt->json) {
     my $prereqs = $self->prereqs($self->zilla);
+    $prereqs = filter_core($prereqs, $omit_core) if $omit_core;
     my $output = $prereqs->as_string_hash;
 
-    require JSON; JSON->VERSION(2);
-    print JSON->new->ascii(1)->canonical(1)->pretty->encode($output), "\n";
+    require JSON::MaybeXS;
+    print JSON::MaybeXS->new(ascii => 1, canonical => 1, pretty => 1)->encode($output), "\n";
     return 1;
   }
 
-  my %modules = $self->extract_dependencies($self->zilla, \@phases, $opt->missing);
+  my %modules = $self->extract_dependencies($self->zilla, \@phases, $opt->missing, $opt->omit_core);
 
   if($opt->versions) {
     for(sort { lc $a cmp lc $b } keys %modules) {
@@ -144,7 +168,7 @@ Dist::Zilla::App::Command::listdeps - print your distribution's prerequisites
 
 =head1 VERSION
 
-version 5.020
+version 5.043
 
 =head1 SYNOPSIS
 
@@ -159,7 +183,7 @@ quick go.
 
 =head1 OPTIONS
 
-=head2 --author
+=head2 --author (or --develop)
 
 Include author dependencies (those listed under C<develop_requires>).
 
@@ -188,7 +212,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
