@@ -1,17 +1,33 @@
 use strict;
 use warnings;
 package Dist::Zilla::App::Command::setup;
-{
-  $Dist::Zilla::App::Command::setup::VERSION = '5.008';
-}
 # ABSTRACT: set up a basic global config file
+$Dist::Zilla::App::Command::setup::VERSION = '5.043';
 use Dist::Zilla::App -command;
 
+#pod =head1 SYNOPSIS
+#pod
+#pod   $ dzil setup
+#pod   Enter your name> Ricardo Signes
+#pod   ...
+#pod
+#pod Dist::Zilla looks for per-user configuration in F<~/.dzil/config.ini>.  This
+#pod command prompts the user for some basic information that can be used to produce
+#pod the most commonly needed F<config.ini> sections.
+#pod
+#pod B<WARNING>: PAUSE account details are stored within config.ini in plain text.
+#pod
+#pod =cut
 
 use autodie;
 
 sub abstract { 'set up a basic global config file' }
 
+sub description {
+  "This command will run through a short interactive process to set up\n" .
+  "a basic Dist::Zilla configuration in ~/.dzil/config.ini"
+}
+
 sub validate_args {
   my ($self, $opt, $args) = @_;
 
@@ -23,6 +39,7 @@ sub execute {
 
   my $chrome = $self->app->chrome;
 
+  require Dist::Zilla::Util;
   my $config_root = Dist::Zilla::Util->_global_config_root;
 
   if (
@@ -77,7 +94,9 @@ sub execute {
 
   if (
     $chrome->prompt_yn(
-      'Do you want to enter your PAUSE account details? ',
+    '
+    * WARNING - Your account details will be stored in plain text *
+Do you want to enter your PAUSE account details? ',
       { default => 0 },
     )
   ) {
@@ -104,6 +123,8 @@ sub execute {
   }
 
   $config_root->mkpath unless -d $config_root;
+  $config_root->subdir('profiles')->mkpath
+    unless -d $config_root->subdir('profiles');
 
   my $umask = umask;
   umask( $umask | 077 ); # this file might contain PAUSE pw; make it go-r
@@ -147,7 +168,7 @@ Dist::Zilla::App::Command::setup - set up a basic global config file
 
 =head1 VERSION
 
-version 5.008
+version 5.043
 
 =head1 SYNOPSIS
 
@@ -159,13 +180,15 @@ Dist::Zilla looks for per-user configuration in F<~/.dzil/config.ini>.  This
 command prompts the user for some basic information that can be used to produce
 the most commonly needed F<config.ini> sections.
 
+B<WARNING>: PAUSE account details are stored within config.ini in plain text.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
