@@ -2,12 +2,12 @@ use strict;
 use warnings;
 package Dist::Zilla::App::Command::test;
 # ABSTRACT: test your dist
-$Dist::Zilla::App::Command::test::VERSION = '5.020';
+$Dist::Zilla::App::Command::test::VERSION = '5.043';
 use Dist::Zilla::App -command;
 
 #pod =head1 SYNOPSIS
 #pod
-#pod   dzil test [ --release ] [ --no-author ] [ --automated ] [ --all ]
+#pod   dzil test [ --release ] [ --no-author ] [ --automated ] [ --extended ] [ --all ]
 #pod
 #pod =head1 DESCRIPTION
 #pod
@@ -31,10 +31,12 @@ use Dist::Zilla::App -command;
 sub opt_spec {
   [ 'release'   => 'enables the RELEASE_TESTING env variable', { default => 0 } ],
   [ 'automated' => 'enables the AUTOMATED_TESTING env variable', { default => 0 } ],
+  [ 'extended' => 'enables the EXTENDED_TESTING env variable', { default => 0 } ],
   [ 'author!' => 'enables the AUTHOR_TESTING env variable (default behavior)', { default => 1 } ],
-  [ 'all' => 'enables the RELEASE_TESTING, AUTOMATED_TESTING and AUTHOR_TESTING env variables', { default => 0 } ],
+  [ 'all' => 'enables the RELEASE_TESTING, AUTOMATED_TESTING, EXTENDED_TESTING and AUTHOR_TESTING env variables', { default => 0 } ],
   [ 'keep-build-dir|keep' => 'keep the build directory even after a success' ],
   [ 'jobs|j=i' => 'number of parallel test jobs to run' ],
+  [ 'test-verbose' => 'enables verbose testing (TEST_VERBOSE env variable on Makefile.PL, --verbose on Build.PL', { default => 0 } ],
 }
 
 #pod =head1 OPTIONS
@@ -47,13 +49,17 @@ sub opt_spec {
 #pod
 #pod This will run the test suite with AUTOMATED_TESTING=1
 #pod
+#pod =head2 --extended
+#pod
+#pod This will run the test suite with EXTENDED_TESTING=1
+#pod
 #pod =head2 --no-author
 #pod
 #pod This will run the test suite without setting AUTHOR_TESTING
 #pod
 #pod =head2 --all
 #pod
-#pod Equivalent to --release --automated --author
+#pod Equivalent to --release --automated --extended --author
 #pod
 #pod =cut
 
@@ -65,6 +71,7 @@ sub execute {
   local $ENV{RELEASE_TESTING} = 1 if $opt->release or $opt->all;
   local $ENV{AUTHOR_TESTING} = 1 if $opt->author or $opt->all;
   local $ENV{AUTOMATED_TESTING} = 1 if $opt->automated or $opt->all;
+  local $ENV{EXTENDED_TESTING} = 1 if $opt->extended or $opt->all;
 
   $self->zilla->test({
     $opt->keep_build_dir
@@ -73,6 +80,9 @@ sub execute {
     $opt->jobs
       ? (jobs => $opt->jobs)
       : (),
+	$opt->test_verbose
+	  ? (test_verbose => $opt->test_verbose)
+	  : (),
   });
 }
 
@@ -90,11 +100,11 @@ Dist::Zilla::App::Command::test - test your dist
 
 =head1 VERSION
 
-version 5.020
+version 5.043
 
 =head1 SYNOPSIS
 
-  dzil test [ --release ] [ --no-author ] [ --automated ] [ --all ]
+  dzil test [ --release ] [ --no-author ] [ --automated ] [ --extended ] [ --all ]
 
 =head1 DESCRIPTION
 
@@ -123,13 +133,17 @@ This will run the test suite with RELEASE_TESTING=1
 
 This will run the test suite with AUTOMATED_TESTING=1
 
+=head2 --extended
+
+This will run the test suite with EXTENDED_TESTING=1
+
 =head2 --no-author
 
 This will run the test suite without setting AUTHOR_TESTING
 
 =head2 --all
 
-Equivalent to --release --automated --author
+Equivalent to --release --automated --extended --author
 
 =head1 AUTHOR
 
@@ -137,7 +151,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
