@@ -2,11 +2,14 @@ use strict;
 use warnings;
 package Dist::Zilla::App::Command::version;
 # ABSTRACT: display dzil's version
-$Dist::Zilla::App::Command::version::VERSION = '5.020';
+$Dist::Zilla::App::Command::version::VERSION = '5.043';
 use Dist::Zilla::App -command;
-use Moose;
-extends 'App::Cmd::Command::version';
-
+use App::Cmd::Command::version;
+BEGIN {
+  ## parent and base dont work here. ??? -- kentnl 2014-10-31
+  our @ISA;
+  unshift @ISA, 'App::Cmd::Command::version';
+}
 
 #pod =head1 SYNOPSIS
 #pod
@@ -37,7 +40,7 @@ Dist::Zilla::App::Command::version - display dzil's version
 
 =head1 VERSION
 
-version 5.020
+version 5.043
 
 =head1 SYNOPSIS
 
@@ -51,7 +54,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
