@@ -1,10 +1,9 @@
 package Dist::Zilla::Dist::Builder;
 # ABSTRACT: dist zilla subclass for building dists
-$Dist::Zilla::Dist::Builder::VERSION = '5.020';
+$Dist::Zilla::Dist::Builder::VERSION = '5.043';
 use Moose 0.92; # role composition fixes
 extends 'Dist::Zilla';
 
-use Moose::Autobox 0.09; # ->flatten
 use MooseX::Types::Moose qw(HashRef);
 use MooseX::Types::Path::Class qw(Dir File);
 
@@ -64,12 +63,11 @@ sub _setup_default_plugins {
         my ($file, $self) = @_;
         local $_ = $file->name;
         return 1 if m{\Alib/} and m{\.(pm|pod)$};
-        return 1 if $_ eq $self->zilla->main_module;
         return;
       },
     });
 
-    $self->plugins->push($plugin);
+    push @{ $self->plugins }, $plugin;
   }
 
   unless ($self->plugin_named(':IncModules')) {
@@ -86,7 +84,7 @@ sub _setup_default_plugins {
       },
     });
 
-    $self->plugins->push($plugin);
+    push @{ $self->plugins }, $plugin;
   }
 
   unless ($self->plugin_named(':TestFiles')) {
@@ -98,7 +96,19 @@ sub _setup_default_plugins {
       code        => sub { local $_ = $_->name; m{\At/} },
     });
 
-    $self->plugins->push($plugin);
+    push @{ $self->plugins }, $plugin;
+  }
+
+  unless ($self->plugin_named(':ExtraTestFiles')) {
+    require Dist::Zilla::Plugin::FinderCode;
+    my $plugin = Dist::Zilla::Plugin::FinderCode->new({
+      plugin_name => ':ExtraTestFiles',
+      zilla       => $self,
+      style       => 'grep',
+      code        => sub { local $_ = $_->name; m{\Axt/} },
+    });
+
+    push @{ $self->plugins }, $plugin;
   }
 
   unless ($self->plugin_named(':ExecFiles')) {
@@ -115,7 +125,26 @@ sub _setup_default_plugins {
       },
     });
 
-    $self->plugins->push($plugin);
+    push @{ $self->plugins }, $plugin;
+  }
+
+  unless ($self->plugin_named(':PerlExecFiles')) {
+    require Dist::Zilla::Plugin::FinderCode;
+    my $plugin = Dist::Zilla::Plugin::FinderCode->new({
+      plugin_name => ':PerlExecFiles',
+      zilla       => $self,
+      style       => 'list',
+      code        => sub {
+        my $parent_plugin = $self->plugin_named(':ExecFiles');
+        my @files = grep {
+          $_->name =~ m{\.pl$}
+              or $_->content =~ m{^\s*\#\!.*perl\b};
+        } @{ $parent_plugin->find_files };
+        return \@files;
+      },
+    });
+
+    push @{ $self->plugins }, $plugin;
   }
 
   unless ($self->plugin_named(':ShareFiles')) {
@@ -129,22 +158,20 @@ sub _setup_default_plugins {
         my $map = $self->zilla->_share_dir_map;
         my @files;
         if ( $map->{dist} ) {
-          push @files, $self->zilla->files->grep(sub {
-            $_->name =~ m{\A\Q$map->{dist}\E/}
-          })->flatten;
+          push @files, grep {; $_->name =~ m{\A\Q$map->{dist}\E/} }
+                       @{ $self->zilla->files };
         }
         if ( my $mod_map = $map->{module} ) {
           for my $mod ( keys %$mod_map ) {
-            push @files, $self->zilla->files->grep(sub {
-              $_->name =~ m{\A\Q$mod_map->{$mod}\E/}
-            })->flatten;
+            push @files, grep { $_->name =~ m{\A\Q$mod_map->{$mod}\E/} }
+                         @{ $self->zilla->files };
           }
         }
         return \@files;
       },
     });
 
-    $self->plugins->push($plugin);
+    push @{ $self->plugins }, $plugin;
   }
 
   unless ($self->plugin_named(':MainModule')) {
@@ -161,7 +188,7 @@ sub _setup_default_plugins {
       },
     });
 
-    $self->plugins->push($plugin);
+    push @{ $self->plugins }, $plugin;
   }
 
   unless ($self->plugin_named(':AllFiles')) {
@@ -173,7 +200,7 @@ sub _setup_default_plugins {
       code        => sub { return 1 },
     });
 
-    $self->plugins->push($plugin);
+    push @{ $self->plugins }, $plugin;
   }
 
   unless ($self->plugin_named(':NoFiles')) {
@@ -185,7 +212,7 @@ sub _setup_default_plugins {
       code        => sub { return },
     });
 
-    $self->plugins->push($plugin);
+    push @{ $self->plugins }, $plugin;
   }
 }
 
@@ -202,7 +229,7 @@ sub _build_share_dir_map {
 
   my $share_dir_map = {};
 
-  for my $plugin ( $self->plugins_with(-ShareDir)->flatten ) {
+  for my $plugin (@{ $self->plugins_with(-ShareDir) }) {
     next unless my $sub_map = $plugin->share_dir_map;
 
     if ( $sub_map->{dist} ) {
@@ -270,8 +297,8 @@ sub _load_config {
     };
 
     my $package = $_->package;
+    my $bundle  = $_->section_name =~ m{^@(?!.*/)} ? ' bundle' : '';
 
-    my $bundle = $package =~ /^@/ ? ' bundle' : '';
     die <<"END_DIE";
 Required plugin$bundle $package isn't installed.
 
@@ -314,26 +341,26 @@ sub build_in {
   $self->log_fatal("attempted to build " . $self->name . " a second time")
     if $self->built_in;
 
-  $_->before_build for $self->plugins_with(-BeforeBuild)->flatten;
+  $_->before_build for @{ $self->plugins_with(-BeforeBuild) };
 
   $self->log("beginning to build " . $self->name);
 
-  $_->gather_files       for $self->plugins_with(-FileGatherer)->flatten;
-  $_->set_file_encodings for $self->plugins_with(-EncodingProvider)->flatten;
-  $_->prune_files        for $self->plugins_with(-FilePruner)->flatten;
+  $_->gather_files       for @{ $self->plugins_with(-FileGatherer) };
+  $_->set_file_encodings for @{ $self->plugins_with(-EncodingProvider) };
+  $_->prune_files        for @{ $self->plugins_with(-FilePruner) };
 
   $self->version; # instantiate this lazy attribute now that files are gathered
 
-  $_->munge_files        for $self->plugins_with(-FileMunger)->flatten;
+  $_->munge_files        for @{ $self->plugins_with(-FileMunger) };
 
-  $_->register_prereqs   for $self->plugins_with(-PrereqSource)->flatten;
+  $_->register_prereqs   for @{ $self->plugins_with(-PrereqSource) };
 
   $self->prereqs->finalize;
 
   # Barf if someone has already set up a prereqs entry? -- rjbs, 2010-04-13
   $self->distmeta->{prereqs} = $self->prereqs->as_string_hash;
 
-  $_->setup_installer for $self->plugins_with(-InstallTool)->flatten;
+  $_->setup_installer for @{ $self->plugins_with(-InstallTool) };
 
   $self->_check_dupe_files;
 
@@ -341,12 +368,12 @@ sub build_in {
 
   $self->log("writing " . $self->name . " in $build_root");
 
-  for my $file ($self->files->flatten) {
+  for my $file (@{ $self->files }) {
     $self->_write_out_file($file, $build_root);
   }
 
   $_->after_build({ build_root => $build_root })
-    for $self->plugins_with(-AfterBuild)->flatten;
+    for @{ $self->plugins_with(-AfterBuild) };
 
   $self->built_in($build_root);
 }
@@ -417,8 +444,9 @@ sub dist_basename {
 #pod   my $tarball = $zilla->archive_filename;
 #pod
 #pod This method will return the filename (e.g. C<Dist-Name-1.01.tar.gz>)
-#pod of the tarball of this dist.  It will include C<-TRIAL> if building a
-#pod trial dist.  The tarball might not exist.
+#pod of the tarball of this distribution.  It will include C<-TRIAL> if building a
+#pod trial distribution, unless the version contains an underscore.  The tarball
+#pod might not exist.
 #pod
 #pod =cut
 
@@ -426,7 +454,7 @@ sub archive_filename {
   my ($self) = @_;
   return join(q{},
     $self->dist_basename,
-    ( $self->is_trial ? '-TRIAL' : '' ),
+    ( $self->is_trial && $self->version !~ /_/ ? '-TRIAL' : '' ),
     '.tar.gz'
   );
 }
@@ -448,7 +476,7 @@ sub build_archive {
   my $basename = $self->dist_basename;
   my $basedir = dir($basename);
 
-  $_->before_archive for $self->plugins_with(-BeforeArchive)->flatten;
+  $_->before_archive for @{ $self->plugins_with(-BeforeArchive) };
 
   my $method = Class::Load::load_optional_class('Archive::Tar::Wrapper',
                                                 { -version => 0.15 })
@@ -474,7 +502,7 @@ sub _build_archive {
   my $archive = Archive::Tar->new;
   my %seen_dir;
   for my $distfile (
-    sort { length($a->name) <=> length($b->name) } $self->files->flatten
+    sort { length($a->name) <=> length($b->name) } @{ $self->files }
   ) {
     my $in = file($distfile->name)->dir;
 
@@ -505,7 +533,7 @@ sub _build_archive_with_wrapper {
   my $archive = Archive::Tar::Wrapper->new;
 
   for my $distfile (
-    sort { length($a->name) <=> length($b->name) } $self->files->flatten
+    sort { length($a->name) <=> length($b->name) } @{ $self->files }
   ) {
     my $in = file($distfile->name)->dir;
 
@@ -529,7 +557,21 @@ sub _prep_build_root {
 
   my $dist_root = $self->root;
 
-  $build_root->rmtree if -d $build_root;
+  return $build_root if !-d $build_root;
+
+  my $res = $build_root->rmtree; # this warns with error details
+  die "unable to delete '$build_root' in preparation of build" if !$res;
+
+  # the following is done only on windows, and only if the deletion failed,
+  # yet rmtree reported success, because currently rmdir is non-blocking as per:
+  # https://rt.perl.org/Ticket/Display.html?id=123958
+  if ( $^O eq 'MSWin32' and -d $build_root ) {
+    $self->log("spinning for at least one second to allow other processes to release locks on $build_root");
+    my $timeout = time + 2;
+    while(time != $timeout and -d $build_root) { }
+    die "unable to delete '$build_root' in preparation of build because some process has a lock on it"
+      if -d $build_root;
+  }
 
   return $build_root;
 }
@@ -548,20 +590,20 @@ sub release {
   my $self = shift;
 
   Carp::croak("you can't release without any Releaser plugins")
-    unless my @releasers = $self->plugins_with(-Releaser)->flatten;
+    unless my @releasers = @{ $self->plugins_with(-Releaser) };
 
   $ENV{DZIL_RELEASING} = 1;
 
   my $tgz = $self->build_archive;
 
   # call all plugins implementing BeforeRelease role
-  $_->before_release($tgz) for $self->plugins_with(-BeforeRelease)->flatten;
+  $_->before_release($tgz) for @{ $self->plugins_with(-BeforeRelease) };
 
   # do the actual release
   $_->release($tgz) for @releasers;
 
   # call all plugins implementing AfterRelease role
-  $_->after_release($tgz) for $self->plugins_with(-AfterRelease)->flatten;
+  $_->after_release($tgz) for @{ $self->plugins_with(-AfterRelease) };
 }
 
 #pod =method clean
@@ -703,7 +745,7 @@ sub test {
   my ($self, $arg) = @_;
 
   Carp::croak("you can't test without any TestRunner plugins")
-    unless my @testers = $self->plugins_with(-TestRunner)->flatten;
+    unless my @testers = @{ $self->plugins_with(-TestRunner) };
 
   my ($target, $latest) = $self->ensure_built_in_tmpdir;
   my $error  = $self->run_tests_in($target, $arg);
@@ -735,7 +777,7 @@ sub run_tests_in {
   my ($self, $target, $arg) = @_;
 
   Carp::croak("you can't test without any TestRunner plugins")
-    unless my @testers = $self->plugins_with(-TestRunner)->flatten;
+    unless my @testers = @{ $self->plugins_with(-TestRunner) };
 
   for my $tester (@testers) {
     my $wd = File::pushd::pushd($target);
@@ -748,7 +790,8 @@ sub run_tests_in {
 #pod   $zilla->run_in_build( \@cmd );
 #pod
 #pod This method makes a temporary directory, builds the distribution there,
-#pod executes the dist's first L<BuildRunner|Dist::Zilla::Role::BuildRunner>, and
+#pod executes all the dist's L<BuildRunner|Dist::Zilla::Role::BuildRunner>s
+#pod (unless directed not to, via C<< $arg->{build} = 0 >>), and
 #pod then runs the given command in the build directory.  If the command exits
 #pod non-zero, the directory will be left in place.
 #pod
@@ -757,11 +800,9 @@ sub run_tests_in {
 sub run_in_build {
   my ($self, $cmd, $arg) = @_;
 
-  # The sort below is a cheap hack to get ModuleBuild ahead of
-  # ExtUtils::MakeMaker. -- rjbs, 2010-01-05
   $self->log_fatal("you can't build without any BuildRunner plugins")
-    unless my @builders =
-    $self->plugins_with(-BuildRunner)->sort->reverse->flatten;
+    unless ($arg and exists $arg->{build} and ! $arg->{build})
+        or @{ $self->plugins_with(-BuildRunner) };
 
   require "Config.pm"; # skip autoprereq
 
@@ -777,7 +818,7 @@ sub run_in_build {
       return 1;
     }
 
-    $builders[0]->build;
+    $self->_ensure_blib;
 
     local $ENV{PERL5LIB} = join $Config::Config{path_sep},
       (map { $abstarget->subdir('blib', $_) } qw(arch lib)),
@@ -802,6 +843,21 @@ sub run_in_build {
   }
 }
 
+# Ensures that a F<blib> directory exists in the build, by invoking all
+# C<-BuildRunner> plugins to generate it.  Useful for commands that operate on
+# F<blib>, such as C<test> or C<run>.
+
+sub _ensure_blib {
+  my ($self) = @_;
+
+  unless ( -d 'blib' ) {
+    my @builders = @{ $self->plugins_with( -BuildRunner ) };
+    $self->log_fatal("no BuildRunner plugins specified") unless @builders;
+    $_->build for @builders;
+    $self->log_fatal("no blib; failed to build properly?") unless -d 'blib';
+  }
+}
+
 __PACKAGE__->meta->make_immutable;
 1;
 
@@ -817,7 +873,7 @@ Dist::Zilla::Dist::Builder - dist zilla subclass for building dists
 
 =head1 VERSION
 
-version 5.020
+version 5.043
 
 =head1 ATTRIBUTES
 
@@ -882,8 +938,9 @@ does not include C<-TRIAL>, even if building a trial dist.
   my $tarball = $zilla->archive_filename;
 
 This method will return the filename (e.g. C<Dist-Name-1.01.tar.gz>)
-of the tarball of this dist.  It will include C<-TRIAL> if building a
-trial dist.  The tarball might not exist.
+of the tarball of this distribution.  It will include C<-TRIAL> if building a
+trial distribution, unless the version contains an underscore.  The tarball
+might not exist.
 
 =head2 build_archive
 
@@ -959,7 +1016,8 @@ does it clean up C<$directory> afterwards.
   $zilla->run_in_build( \@cmd );
 
 This method makes a temporary directory, builds the distribution there,
-executes the dist's first L<BuildRunner|Dist::Zilla::Role::BuildRunner>, and
+executes all the dist's L<BuildRunner|Dist::Zilla::Role::BuildRunner>s
+(unless directed not to, via C<< $arg->{build} = 0 >>), and
 then runs the given command in the build directory.  If the command exits
 non-zero, the directory will be left in place.
 
@@ -969,7 +1027,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
