@@ -1,11 +1,10 @@
 package Dist::Zilla::Dist::Minter;
 # ABSTRACT: distribution builder; installer not included!
-$Dist::Zilla::Dist::Minter::VERSION = '5.020';
+$Dist::Zilla::Dist::Minter::VERSION = '5.043';
 use Moose 0.92; # role composition fixes
 extends 'Dist::Zilla';
 
 use File::pushd ();
-use Moose::Autobox;
 use Path::Class;
 
 use namespace::autoclean;
@@ -20,7 +19,7 @@ sub _setup_default_plugins {
       zilla       => $self,
     });
 
-    $self->plugins->push($plugin);
+    push @{ $self->plugins }, $plugin;
   }
 }
 
@@ -104,7 +103,7 @@ sub mint_dist {
 
   my $wd = File::pushd::pushd($self->root);
 
-  $_->before_mint  for $self->plugins_with(-BeforeMint)->flatten;
+  $_->before_mint  for @{ $self->plugins_with(-BeforeMint) };
 
   for my $module (@modules) {
     my $minter = $self->plugin_named(
@@ -114,21 +113,21 @@ sub mint_dist {
     $minter->make_module({ name => $module->{name} })
   }
 
-  $_->gather_files       for $self->plugins_with(-FileGatherer)->flatten;
-  $_->set_file_encodings for $self->plugins_with(-EncodingProvider)->flatten;
-  $_->prune_files        for $self->plugins_with(-FilePruner)->flatten;
-  $_->munge_files        for $self->plugins_with(-FileMunger)->flatten;
+  $_->gather_files       for @{ $self->plugins_with(-FileGatherer) };
+  $_->set_file_encodings for @{ $self->plugins_with(-EncodingProvider) };
+  $_->prune_files        for @{ $self->plugins_with(-FilePruner) };
+  $_->munge_files        for @{ $self->plugins_with(-FileMunger) };
 
   $self->_check_dupe_files;
 
   $self->log("writing files to $dir");
 
-  for my $file ($self->files->flatten) {
+  for my $file (@{ $self->files }) {
     $self->_write_out_file($file, $dir);
   }
 
   $_->after_mint({ mint_root => $dir })
-    for $self->plugins_with(-AfterMint)->flatten;
+    for @{ $self->plugins_with(-AfterMint) };
 
   $self->log("dist minted in ./$name");
 }
@@ -148,7 +147,7 @@ Dist::Zilla::Dist::Minter - distribution builder; installer not included!
 
 =head1 VERSION
 
-version 5.020
+version 5.043
 
 =head1 AUTHOR
 
@@ -156,7 +155,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
