@@ -1,16 +1,35 @@
 package Dist::Zilla::MVP::Assembler;
-{
-  $Dist::Zilla::MVP::Assembler::VERSION = '5.008';
-}
+# ABSTRACT: Dist::Zilla-specific subclass of Config::MVP::Assembler
+$Dist::Zilla::MVP::Assembler::VERSION = '5.043';
 use Moose;
 extends 'Config::MVP::Assembler';
-with 'Config::MVP::Assembler::WithBundles';
-# ABSTRACT: Dist::Zilla-specific subclass of Config::MVP::Assembler
+with 'Config::MVP::Assembler::WithBundles' => { -version => '2.200010' };
 
 use namespace::autoclean;
 
 use Dist::Zilla::Util;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod B<Take this next bit seriously!>  If you don't understand how L<Config::MVP>
+#pod works, reading about how the Dist::Zilla-specific Assembler works is not going
+#pod to be useful.
+#pod
+#pod Dist::Zilla::MVP::Assembler extends L<Config::MVP::Assembler> and composes
+#pod L<Config::MVP::Assembler::WithBundles>.  For potential plugin bundles (things
+#pod composing L<Dist::Zilla::Role::PluginBundle>)
+#pod
+#pod The Assembler has chrome, so it can log and will (eventually) be able to get
+#pod input from the user.
+#pod
+#pod The Assembler's C<expand_package> method delegates to Dist::Zilla::Util's
+#pod L<expand_config_package_name|Dist::Zilla::Util/expand_config_package_name>
+#pod method.
+#pod
+#pod The Assembler will throw an exception if it is instructed to add a value for
+#pod C<plugin_name> or C<zilla>.
+#pod
+#pod =cut
 
 has chrome => (
   is   => 'rw',
@@ -65,7 +84,7 @@ Dist::Zilla::MVP::Assembler - Dist::Zilla-specific subclass of Config::MVP::Asse
 
 =head1 VERSION
 
-version 5.008
+version 5.043
 
 =head1 DESCRIPTION
 
@@ -93,7 +112,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
