@@ -1,14 +1,29 @@
 package Dist::Zilla::MVP::Section;
 # ABSTRACT: a standard section in Dist::Zilla's configuration sequence
-$Dist::Zilla::MVP::Section::VERSION = '5.020';
+$Dist::Zilla::MVP::Section::VERSION = '5.043';
 use Moose;
 extends 'Config::MVP::Section';
 
 use namespace::autoclean;
 
-use Config::MVP::Section 2.200002; # for not-installed error
+use Config::MVP::Section 2.200009; # not-installed error with section_name
 
-use Moose::Autobox;
+around add_value => sub {
+  my ($orig, $self, $name, $value) = @_;
+
+  if ($name =~ s/\A://) {
+    if ($name eq 'version') {
+      Dist::Zilla::Util->_assert_loaded_class_version_ok(
+        $self->package,
+        $value,
+      );
+    }
+
+    return;
+  }
+
+  $self->$orig($name, $value);
+};
 
 after finalize => sub {
   my ($self) = @_;
@@ -21,16 +36,6 @@ after finalize => sub {
 
   my %payload = %{ $self->payload };
 
-  my %dzil;
-  $dzil{$_} = delete $payload{":$_"} for grep { s/\A:// } keys %payload;
-
-  if (defined $dzil{version}) {
-    Dist::Zilla::Util->_assert_loaded_class_version_ok(
-      $plugin_class,
-      $dzil{version},
-    );
-  }
-
   $plugin_class->register_component($name, \%payload, $self);
 
   return;
@@ -51,7 +56,7 @@ Dist::Zilla::MVP::Section - a standard section in Dist::Zilla's configuration se
 
 =head1 VERSION
 
-version 5.020
+version 5.043
 
 =head1 AUTHOR
 
@@ -59,7 +64,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
