@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::AutoPrereqs;
 # ABSTRACT: automatically extract prereqs from your modules
-$Dist::Zilla::Plugin::AutoPrereqs::VERSION = '5.020';
+$Dist::Zilla::Plugin::AutoPrereqs::VERSION = '5.043';
 use Moose;
 with(
   'Dist::Zilla::Role::PrereqSource',
@@ -18,6 +18,11 @@ with(
     finder_arg_names => [ 'configure_finder' ],
     default_finders  => [],
   },
+  'Dist::Zilla::Role::FileFinderUser' => {
+    method           => 'found_develop_files',
+    finder_arg_names => [ 'develop_finder' ],
+    default_finders  => [ ':ExtraTestFiles' ],
+  },
 );
 
 #pod =attr finder
@@ -38,16 +43,15 @@ with(
 #pod no default value; AutoPrereqs will not determine configure-phase
 #pod prerequisites unless you set configure_finder.
 #pod
+#pod =attr develop_finder
+#pod
+#pod Just like C<finder>, but for develop-phase prerequisites.  The default value
+#pod is C<:ExtraTestFiles>.
+#pod
 #pod =cut
 
 use namespace::autoclean;
 
-use List::AllUtils 'uniq';
-use Moose::Autobox;
-use Perl::PrereqScanner 1.016; # don't skip "lib"
-use CPAN::Meta::Requirements;
-use version;
-
 #pod =head1 SYNOPSIS
 #pod
 #pod In your F<dist.ini>:
@@ -66,16 +70,25 @@ use version;
 #pod
 #pod This plugin will skip the modules shipped within your dist.
 #pod
+#pod B<Note>, if you have any non-Perl files in your C<t/> directory or other
+#pod directories being scanned, be sure to mark those files' encoding as C<bytes>
+#pod with the L<Encoding|Dist::Zilla::Plugin::Encoding> plugin so they won't be
+#pod scanned:
+#pod
+#pod     [Encoding]
+#pod     encoding = bytes
+#pod     match    = ^t/data/
+#pod
 #pod =attr extra_scanners
 #pod
-#pod This is an arrayref of scanner names (as expected by Perl::PrereqScanner).
-#pod It will be passed as the C<extra_scanners> parameter to Perl::PrereqScanner.
+#pod This is an arrayref of scanner names (as expected by L<Perl::PrereqScanner>).
+#pod It will be passed as the C<extra_scanners> parameter to L<Perl::PrereqScanner>.
 #pod
 #pod =attr scanners
 #pod
-#pod This is an arrayref of scanner names (as expected by Perl::PrereqScanner).
+#pod This is an arrayref of scanner names (as expected by L<Perl::PrereqScanner>).
 #pod If present, it will be passed as the C<scanners> parameter to
-#pod Perl::PrereqScanner, which means that it will replace the default list
+#pod L<Perl::PrereqScanner>, which means that it will replace the default list
 #pod of scanners.
 #pod
 #pod =attr skips
@@ -118,6 +131,11 @@ has skips => (
 sub register_prereqs {
   my $self  = shift;
 
+  require Perl::PrereqScanner;
+  Perl::PrereqScanner->VERSION('1.016'); # don't skip "lib"
+  require CPAN::Meta::Requirements;
+  require List::MoreUtils;  # uniq
+
   my @modules;
 
   my $scanner = Perl::PrereqScanner->new(
@@ -125,10 +143,13 @@ sub register_prereqs {
     extra_scanners => $self->extra_scanners,
   );
 
+  # not a hash, because order is important
   my @sets = (
+    # phase => file finder method
     [ configure => 'found_configure_files' ], # must come before runtime
     [ runtime => 'found_files'      ],
     [ test    => 'found_test_files' ],
+    [ develop => 'found_develop_files' ],
   );
 
   my %runtime_final;
@@ -150,6 +171,8 @@ sub register_prereqs {
 
       # store module name, to trim it from require list later on
       my @this_thing = $file->name;
+
+      # t/lib/Foo.pm is treated as providing t::lib::Foo, lib::Foo, and Foo
       if ($this_thing[0] =~ /^t/) {
         push @this_thing, ($this_thing[0]) x 2;
         $this_thing[1] =~ s{^t/}{};
@@ -157,12 +180,16 @@ sub register_prereqs {
       } else {
         $this_thing[0] =~ s{^lib/}{};
       }
-      @this_thing = uniq @this_thing;
       s{\.pm$}{} for @this_thing;
       s{/}{::}g for @this_thing;
+
+      # this is a bunk heuristic and can still capture strings from pod - the
+      # proper thing to do is grab all packages from Module::Metadata
+      push @this_thing, $file->content =~ /^[^#]*?(?:^|\s)package\s+([^\s;#]+)/mg;
       push @modules, @this_thing;
 
       # parse a file, and merge with existing prereqs
+      $self->log_debug([ 'scanning %s for %s prereqs', $file->name, $phase ]);
       my $file_req = $scanner->scan_ppi_document(
         $self->ppi_document_for_file($file)
       );
@@ -170,13 +197,8 @@ sub register_prereqs {
       $req->add_requirements($file_req);
     }
 
-    # remove prereqs shipped with current dist
-    $req->clear_requirement($_) for @modules;
-
-    $req->clear_requirement($_) for qw(Config Errno); # never indexed
-
     # remove prereqs from skiplist
-    for my $skip (($self->skips || [])->flatten) {
+    for my $skip (@{ $self->skips || [] }) {
       my $re   = qr/$skip/;
 
       foreach my $k ($req->required_modules) {
@@ -184,11 +206,18 @@ sub register_prereqs {
       }
     }
 
+    # remove prereqs shipped with current dist
+    $self->log_debug([ 'excluding local packages: %s', sub { join(', ', List::MoreUtils::uniq @modules) } ]);
+    $req->clear_requirement($_) for @modules;
+
+    $req->clear_requirement($_) for qw(Config DB Errno NEXT Pod::Functions); # never indexed
+
     # we're done, return what we've found
     my %got = %{ $req->as_string_hash };
     if ($phase eq 'runtime') {
       %runtime_final = %got;
     } else {
+      # do not test-require things required for runtime
       delete $got{$_} for
         grep { exists $got{$_} and $runtime_final{$_} ge $got{$_} }
         keys %runtime_final;
@@ -213,7 +242,7 @@ Dist::Zilla::Plugin::AutoPrereqs - automatically extract prereqs from your modul
 
 =head1 VERSION
 
-version 5.020
+version 5.043
 
 =head1 SYNOPSIS
 
@@ -233,6 +262,15 @@ L<Prereqs|Dist::Zilla::Plugin::Prereqs> plugin.
 
 This plugin will skip the modules shipped within your dist.
 
+B<Note>, if you have any non-Perl files in your C<t/> directory or other
+directories being scanned, be sure to mark those files' encoding as C<bytes>
+with the L<Encoding|Dist::Zilla::Plugin::Encoding> plugin so they won't be
+scanned:
+
+    [Encoding]
+    encoding = bytes
+    match    = ^t/data/
+
 =head1 ATTRIBUTES
 
 =head2 finder
@@ -253,16 +291,21 @@ Just like C<finder>, but for configure-phase prerequisites.  There is
 no default value; AutoPrereqs will not determine configure-phase
 prerequisites unless you set configure_finder.
 
+=head2 develop_finder
+
+Just like C<finder>, but for develop-phase prerequisites.  The default value
+is C<:ExtraTestFiles>.
+
 =head2 extra_scanners
 
-This is an arrayref of scanner names (as expected by Perl::PrereqScanner).
-It will be passed as the C<extra_scanners> parameter to Perl::PrereqScanner.
+This is an arrayref of scanner names (as expected by L<Perl::PrereqScanner>).
+It will be passed as the C<extra_scanners> parameter to L<Perl::PrereqScanner>.
 
 =head2 scanners
 
-This is an arrayref of scanner names (as expected by Perl::PrereqScanner).
+This is an arrayref of scanner names (as expected by L<Perl::PrereqScanner>).
 If present, it will be passed as the C<scanners> parameter to
-Perl::PrereqScanner, which means that it will replace the default list
+L<Perl::PrereqScanner>, which means that it will replace the default list
 of scanners.
 
 =head2 skips
@@ -285,7 +328,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
