@@ -1,12 +1,11 @@
 package Dist::Zilla::Plugin::DistINI;
 # ABSTRACT: a plugin to add a dist.ini to newly-minted dists
-$Dist::Zilla::Plugin::DistINI::VERSION = '5.020';
+$Dist::Zilla::Plugin::DistINI::VERSION = '5.043';
 use Moose;
 with qw(Dist::Zilla::Role::FileGatherer);
 
 use Dist::Zilla::File::FromCode;
 
-use Moose::Autobox 0.10; # for ->each_value
 use MooseX::Types::Moose qw(ArrayRef Str);
 use Path::Tiny;
 
@@ -66,11 +65,12 @@ sub gather_files {
   my $zilla = $self->zilla;
 
   my $postlude = '';
-  $self->append_file->each_value(sub {
+
+  for (@{ $self->append_file }) {
     my $fn = $self->zilla->root->file($_);
 
     $postlude .= path($fn)->slurp_utf8;
-  });
+  }
 
   my $code = sub {
     my @core_attrs = qw(name authors copyright_holder);
@@ -116,7 +116,7 @@ Dist::Zilla::Plugin::DistINI - a plugin to add a dist.ini to newly-minted dists
 
 =head1 VERSION
 
-version 5.020
+version 5.043
 
 =head1 DESCRIPTION
 
@@ -164,7 +164,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
