@@ -1,14 +1,20 @@
 package Dist::Zilla::Plugin::ExecDir;
-{
-  $Dist::Zilla::Plugin::ExecDir::VERSION = '5.008';
-}
 # ABSTRACT: install a directory's contents as executables
+$Dist::Zilla::Plugin::ExecDir::VERSION = '5.043';
 use Moose;
 
 use namespace::autoclean;
 
-use Moose::Autobox;
-
+#pod =head1 SYNOPSIS
+#pod
+#pod In your F<dist.ini>:
+#pod
+#pod   [ExecDir]
+#pod   dir = scripts
+#pod
+#pod If no C<dir> is provided, the default is F<bin>.
+#pod
+#pod =cut
 
 has dir => (
   is   => 'ro',
@@ -20,7 +26,9 @@ sub find_files {
   my ($self) = @_;
 
   my $dir = $self->dir;
-  my $files = $self->zilla->files->grep(sub { index($_->name, "$dir/") == 0 });
+  my $files = [
+    grep { index($_->name, "$dir/") == 0 } @{ $self->zilla->files }
+  ];
 }
 
 with 'Dist::Zilla::Role::ExecFiles';
@@ -39,7 +47,7 @@ Dist::Zilla::Plugin::ExecDir - install a directory's contents as executables
 
 =head1 VERSION
 
-version 5.008
+version 5.043
 
 =head1 SYNOPSIS
 
@@ -56,7 +64,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
