@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::MakeMaker::Runner;
 # ABSTRACT: Test and build dists with a Makefile.PL
-$Dist::Zilla::Plugin::MakeMaker::Runner::VERSION = '5.020';
+$Dist::Zilla::Plugin::MakeMaker::Runner::VERSION = '5.043';
 use Moose;
 with(
   'Dist::Zilla::Role::BuildRunner',
@@ -27,8 +27,11 @@ sub build {
   return
     if -e $makefile and (stat 'Makefile.PL')[9] <= (stat $makefile)[9];
 
-  system($^X => 'Makefile.PL') and die "error with Makefile.PL\n";
-  system($make)                and die "error running $make\n";
+  $self->log_debug("running $^X Makefile.PL");
+  system($^X => qw(Makefile.PL INSTALLMAN1DIR=none INSTALLMAN3DIR=none)) and die "error with Makefile.PL\n";
+
+  $self->log_debug("running $make");
+  system($make) and die "error running $make\n";
 
   return;
 }
@@ -47,8 +50,9 @@ sub test {
   my $ho = "HARNESS_OPTIONS";
   local $ENV{$ho} = $ENV{$ho} ? "$ENV{$ho}:$jobs" : $jobs;
 
+  $self->log_debug(join(' ', "running $make test", ( $self->zilla->logger->get_debug ? 'TEST_VERBOSE=1' : () )));
   system($make, 'test',
-    ( $self->zilla->logger->get_debug ? 'TEST_VERBOSE=1' : () ),
+    ( $self->zilla->logger->get_debug || $arg->{test_verbose} ? 'TEST_VERBOSE=1' : () ),
   ) and die "error running $make test\n";
 
   return;
@@ -69,7 +73,7 @@ Dist::Zilla::Plugin::MakeMaker::Runner - Test and build dists with a Makefile.PL
 
 =head1 VERSION
 
-version 5.020
+version 5.043
 
 =head1 AUTHOR
 
@@ -77,7 +81,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
