@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::MetaNoIndex;
 # ABSTRACT: Stop CPAN from indexing stuff
-$Dist::Zilla::Plugin::MetaNoIndex::VERSION = '5.020';
+$Dist::Zilla::Plugin::MetaNoIndex::VERSION = '5.043';
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider';
 
@@ -102,7 +102,7 @@ sub metadata {
   my $self = shift;
   return {
     no_index => {
-      map  {; my $reader = $_->[0];  ($_->[1] => $self->$reader) }
+      map  {; my $reader = $_->[0];  ($_->[1] => [ sort @{ $self->$reader } ]) }
       grep {; my $pred   = "_has_$_->[0]"; $self->$pred }
       map  {; [ $_ => $ATTR_ALIAS{$_}[0] ] }
       keys %ATTR_ALIAS
@@ -131,7 +131,7 @@ Dist::Zilla::Plugin::MetaNoIndex - Stop CPAN from indexing stuff
 
 =head1 VERSION
 
-version 5.020
+version 5.043
 
 =head1 SYNOPSIS
 
@@ -203,7 +203,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
