@@ -1,12 +1,10 @@
 package Dist::Zilla::Plugin::ModuleShareDirs;
 # ABSTRACT: install a directory's contents as module-based "ShareDir" content
-$Dist::Zilla::Plugin::ModuleShareDirs::VERSION = '5.020';
+$Dist::Zilla::Plugin::ModuleShareDirs::VERSION = '5.043';
 use Moose;
 
 use namespace::autoclean;
 
-use Moose::Autobox;
-
 #pod =head1 SYNOPSIS
 #pod
 #pod In your F<dist.ini>:
@@ -30,10 +28,9 @@ sub find_files {
 
   for my $mod ( keys %$modmap ) {
     my $dir = $modmap->{$mod};
-    my $mod_files = $self->zilla->files->grep(
-      sub { index($_->name, "$dir/") == 0 }
-    );
-    push @files, @$mod_files;
+    my @mod_files = grep { index($_->name, "$dir/") == 0 }
+      @{ $self->zilla->files };
+    push @files, @mod_files;
   }
 
   return \@files;
@@ -47,9 +44,12 @@ sub share_dir_map {
   return { module => $modmap };
 }
 
-sub BUILDARGS {
+around BUILDARGS => sub {
+  my $orig = shift;
   my ($class, @arg) = @_;
-  my %copy = ref $arg[0] ? %{$arg[0]} : @arg;
+
+  my $args = $class->$orig(@arg);
+  my %copy = %{ $args };
 
   my $zilla = delete $copy{zilla};
   my $name  = delete $copy{plugin_name};
@@ -59,7 +59,7 @@ sub BUILDARGS {
     plugin_name => $name,
     _module_map => \%copy,
   }
-}
+};
 
 with 'Dist::Zilla::Role::ShareDir';
 __PACKAGE__->meta->make_immutable;
@@ -77,7 +77,7 @@ Dist::Zilla::Plugin::ModuleShareDirs - install a directory's contents as module-
 
 =head1 VERSION
 
-version 5.020
+version 5.043
 
 =head1 SYNOPSIS
 
@@ -93,7 +93,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
