@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::NextRelease;
 # ABSTRACT: update the next release number in your changelog
-$Dist::Zilla::Plugin::NextRelease::VERSION = '5.020';
+$Dist::Zilla::Plugin::NextRelease::VERSION = '5.043';
 use namespace::autoclean;
 
 use Moose;
@@ -12,6 +12,7 @@ with (
 
 use Path::Tiny;
 use Moose::Util::TypeConstraints;
+use List::Util 'first';
 use String::Formatter 0.100680 stringf => {
   -as => '_format_version',
 
@@ -35,13 +36,19 @@ use String::Formatter 0.100680 stringf => {
     V => sub { $_[0]->zilla->version
                 . ($_[0]->zilla->is_trial
                    ? (defined $_[1] ? $_[1] : '-TRIAL') : '') },
+    P => sub {
+      my $releaser = first { $_->can('cpanid') } @{ $_[0]->zilla->plugins_with('-Releaser') };
+      $_[0]->log_fatal('releaser doesn\'t provide cpanid, but %P used') unless $releaser;
+      $releaser->cpanid;
+    },
   },
 };
 
+our $DEFAULT_TIME_ZONE = 'local';
 has time_zone => (
   is => 'ro',
   isa => 'Str', # should be more validated later -- apocal
-  default => 'local',
+  default => $DEFAULT_TIME_ZONE,
 );
 
 has format => (
@@ -96,14 +103,23 @@ sub section_header {
   return _format_version($self->format, $self);
 }
 
+has _original_changes_content => (
+  is  => 'rw',
+  isa => 'Str',
+  init_arg => undef,
+);
+
 sub munge_files {
   my ($self) = @_;
 
   my ($file) = grep { $_->name eq $self->filename } @{ $self->zilla->files };
   return unless $file;
 
-  my $content = $self->fill_in_string(
-    $file->content,
+  # save original unmunged content, for replacing back in the repo later
+  my $content = $self->_original_changes_content($file->content);
+
+  $content = $self->fill_in_string(
+    $content,
     {
       dist    => \($self->zilla),
       version => \($self->zilla->version),
@@ -120,10 +136,11 @@ sub after_release {
   my ($self) = @_;
   my $filename = $self->filename;
   my ($gathered_file) = grep { $_->name eq $filename } @{ $self->zilla->files };
+  $self->log_fatal("failed to find $filename in the distribution") if not $gathered_file;
   my $iolayer = sprintf(":raw:encoding(%s)", $gathered_file->encoding);
 
   # read original changelog
-  my $content = path($filename)->slurp({ binmode => $iolayer});
+  my $content = $self->_original_changes_content;
 
   # add the version and date to file content
   my $delim  = $self->delim;
@@ -228,6 +245,10 @@ __PACKAGE__->meta->make_immutable;
 #pod = C<%E>
 #pod The email address of the user making this release (from C<user_stash>).
 #pod
+#pod = C<%P>
+#pod The CPAN (PAUSE) id of the user namking this release (from -Releaser plugins;
+#pod see L<[UploadToCPAN]|Dist::Zilla::Plugin::UploadToCPAN/username>).
+#pod
 #pod = C<%n>
 #pod A newline
 #pod
@@ -260,7 +281,7 @@ Dist::Zilla::Plugin::NextRelease - update the next release number in your change
 
 =head1 VERSION
 
-version 5.020
+version 5.043
 
 =head1 SYNOPSIS
 
@@ -359,6 +380,11 @@ The name of the user making this release (from C<user_stash>).
 
 The email address of the user making this release (from C<user_stash>).
 
+=item C<%P>
+
+The CPAN (PAUSE) id of the user namking this release (from -Releaser plugins;
+see L<[UploadToCPAN]|Dist::Zilla::Plugin::UploadToCPAN/username>).
+
 =item C<%n>
 
 A newline
@@ -387,7 +413,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
