@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::PkgVersion;
 # ABSTRACT: add a $VERSION to your packages
-$Dist::Zilla::Plugin::PkgVersion::VERSION = '5.020';
+$Dist::Zilla::Plugin::PkgVersion::VERSION = '5.043';
 use Moose;
 with(
   'Dist::Zilla::Role::FileMunger',
@@ -10,9 +10,6 @@ with(
   'Dist::Zilla::Role::PPI',
 );
 
-use PPI;
-use MooseX::Types::Perl qw(LaxVersionStr);
-
 use namespace::autoclean;
 
 #pod =head1 SYNOPSIS
@@ -26,7 +23,11 @@ use namespace::autoclean;
 #pod This plugin will add lines like the following to each package in each Perl
 #pod module or program (more or less) within the distribution:
 #pod
-#pod   $MyModule::VERSION = 0.001;
+#pod   $MyModule::VERSION = '0.001';
+#pod
+#pod or
+#pod
+#pod   { our $VERSION = '0.001'; }
 #pod
 #pod ...where 0.001 is the version of the dist, and MyModule is the name of the
 #pod package being given a version.  (In other words, it always uses fully-qualified
@@ -49,13 +50,31 @@ use namespace::autoclean;
 #pod
 #pod =attr die_on_line_insertion
 #pod
-#pod By default, PkgVersion look for a blank line after each C<package> statement.
+#pod By default, PkgVersion looks for a blank line after each C<package> statement.
 #pod If it finds one, it inserts the C<$VERSION> assignment on that line.  If it
 #pod doesn't, it will insert a new line, which means the shipped copy of the module
 #pod will have different line numbers (off by one) than the source.  If
 #pod C<die_on_line_insertion> is true, PkgVersion will raise an exception rather
 #pod than insert a new line.
 #pod
+#pod =attr use_our
+#pod
+#pod The idea here was to insert C<< { our $VERSION = '0.001'; } >> instead of C<<
+#pod $Module::Name::VERSION = '0.001'; >>.  It turns out that this causes problems
+#pod with some analyzers.  Use of this feature is deprecated.
+#pod
+#pod Something else will replace it in the future.
+#pod
+#pod =attr use_begin
+#pod
+#pod If true, the version assignment is wrapped in a BEGIN block.  This may help in
+#pod rare cases, such as when DynaLoader has to be called at BEGIN time, and
+#pod requires VERSION.  This option should be needed rarely.
+#pod
+#pod Also note that assigning to C<$VERSION> before the module has finished
+#pod compiling can lead to confused behavior with attempts to determine whether a
+#pod module was successfully loaded on perl v5.8.
+#pod
 #pod =attr finder
 #pod
 #pod =for stopwords FileFinder
@@ -72,6 +91,12 @@ use namespace::autoclean;
 #pod
 #pod =cut
 
+sub BUILD {
+  my ($self) = @_;
+  $self->log("use_our option to PkgVersion is deprecated and will be removed")
+    if $self->use_our;
+}
+
 sub munge_files {
   my ($self) = @_;
 
@@ -86,6 +111,11 @@ sub munge_file {
     return;
   }
 
+  if ($file->name =~ /\.pod$/) {
+    $self->log_debug($file->name . " is a pod file, skipping...");
+    return;
+  }
+
   return $self->munge_perl($file);
 }
 
@@ -101,16 +131,35 @@ has die_on_line_insertion => (
   default => 0,
 );
 
+has use_our => (
+  is  => 'ro',
+  isa => 'Bool',
+  default => 0,
+);
+
+has use_begin => (
+  is  => 'ro',
+  isa => 'Bool',
+  default => 0,
+);
+
 sub munge_perl {
   my ($self, $file) = @_;
 
   my $version = $self->zilla->version;
 
+  require version;
   Carp::croak("invalid characters in version")
-    unless LaxVersionStr->check($version);
+    unless version::is_lax($version);
 
   my $document = $self->ppi_document_for_file($file);
 
+  my $package_stmts = $document->find('PPI::Statement::Package');
+  unless ($package_stmts) {
+    $self->log_debug([ 'skipping %s: no package statement found', $file->name ]);
+    return;
+  }
+
   if ($self->document_assigns_to_variable($document, '$VERSION')) {
     if ($self->die_on_existing_version) {
       $self->log_fatal([ 'existing assignment to $VERSION in %s', $file->name ]);
@@ -120,12 +169,6 @@ sub munge_perl {
     return;
   }
 
-  my $package_stmts = $document->find('PPI::Statement::Package');
-  unless ($package_stmts) {
-    $self->log_debug([ 'skipping %s: no package statement found', $file->name ]);
-    return;
-  }
-
   my %seen_pkg;
 
   my $munged = 0;
@@ -151,7 +194,12 @@ sub munge_perl {
     # an assignment to version; it shouldn't be needed, but it's been annoying
     # enough in the past that I'm keeping it here until tests are better
     my $trial = $self->zilla->is_trial ? ' # TRIAL' : '';
-    my $perl = "\$$package\::VERSION\x20=\x20'$version';$trial";
+    my $perl = $self->use_our
+        ? "{ our \$VERSION\x20=\x20'$version'; }$trial"
+        : "\$$package\::VERSION\x20=\x20'$version';$trial";
+
+    $self->use_begin
+      and $perl = "BEGIN { $perl }";
 
     $self->log_debug([
       'adding $VERSION assignment to %s in %s',
@@ -164,9 +212,12 @@ sub munge_perl {
     {
       my $curr = $stmt;
       while (1) {
+        # avoid bogus locations due to insert_after
+        $document->flush_locations if $munged;
+        my $curr_line_number = $curr->line_number + 1;
         my $find = $document->find(sub {
-          return $_[1]->line_number == $curr->line_number + 1;
-          return;
+          my $line = $_[1]->line_number;
+          return $line > $curr_line_number ? undef : $line == $curr_line_number;
         });
 
         last unless $find and @$find == 1;
@@ -186,6 +237,13 @@ sub munge_perl {
 
     $perl = $blank ? "$perl\n" : "\n$perl";
 
+    (my $clean_version = $version) =~ tr/_//d;
+    $perl .= (
+      $self->use_our
+        ? "\n\$VERSION\x20=\x20'$clean_version';"
+        : "\n\$$package\::VERSION\x20=\x20'$clean_version';"
+      ) if $version ne $clean_version;
+
     # Why can't I use PPI::Token::Unknown? -- rjbs, 2014-01-11
     my $bogus_token = PPI::Token::Comment->new($perl);
 
@@ -196,8 +254,9 @@ sub munge_perl {
     } else {
       my $method = $self->die_on_line_insertion ? 'log_fatal' : 'log';
       $self->$method([
-        'no blank line for $VERSION after package %s statement on line %s',
+        'no blank line for $VERSION after package %s statement in %s line %s',
         $stmt->namespace,
+        $file->name,
         $stmt->line_number,
       ]);
 
@@ -208,7 +267,8 @@ sub munge_perl {
     $munged = 1;
   }
 
-  $self->save_ppi_document_to_file($document, $file) if $munged;
+  # the document is no longer correct; it must be reparsed before it can be used again
+  $file->encoded_content($document->serialize) if $munged;
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -239,7 +299,7 @@ Dist::Zilla::Plugin::PkgVersion - add a $VERSION to your packages
 
 =head1 VERSION
 
-version 5.020
+version 5.043
 
 =head1 SYNOPSIS
 
@@ -252,7 +312,11 @@ in dist.ini
 This plugin will add lines like the following to each package in each Perl
 module or program (more or less) within the distribution:
 
-  $MyModule::VERSION = 0.001;
+  $MyModule::VERSION = '0.001';
+
+or
+
+  { our $VERSION = '0.001'; }
 
 ...where 0.001 is the version of the dist, and MyModule is the name of the
 package being given a version.  (In other words, it always uses fully-qualified
@@ -277,13 +341,31 @@ false.
 
 =head2 die_on_line_insertion
 
-By default, PkgVersion look for a blank line after each C<package> statement.
+By default, PkgVersion looks for a blank line after each C<package> statement.
 If it finds one, it inserts the C<$VERSION> assignment on that line.  If it
 doesn't, it will insert a new line, which means the shipped copy of the module
 will have different line numbers (off by one) than the source.  If
 C<die_on_line_insertion> is true, PkgVersion will raise an exception rather
 than insert a new line.
 
+=head2 use_our
+
+The idea here was to insert C<< { our $VERSION = '0.001'; } >> instead of C<<
+$Module::Name::VERSION = '0.001'; >>.  It turns out that this causes problems
+with some analyzers.  Use of this feature is deprecated.
+
+Something else will replace it in the future.
+
+=head2 use_begin
+
+If true, the version assignment is wrapped in a BEGIN block.  This may help in
+rare cases, such as when DynaLoader has to be called at BEGIN time, and
+requires VERSION.  This option should be needed rarely.
+
+Also note that assigning to C<$VERSION> before the module has finished
+compiling can lead to confused behavior with attempts to determine whether a
+module was successfully loaded on perl v5.8.
+
 =head2 finder
 
 =for stopwords FileFinder
@@ -315,7 +397,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
