@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::Prereqs;
 # ABSTRACT: list simple prerequisites
-$Dist::Zilla::Plugin::Prereqs::VERSION = '5.020';
+$Dist::Zilla::Plugin::Prereqs::VERSION = '5.043';
 use Moose;
 with 'Dist::Zilla::Role::PrereqSource';
 
@@ -122,9 +122,12 @@ has _prereq => (
 
 sub mvp_aliases { return { -relationship => '-type' } }
 
-sub BUILDARGS {
+around BUILDARGS => sub {
+  my $orig = shift;
   my ($class, @arg) = @_;
-  my %copy = ref $arg[0] ? %{$arg[0]} : @arg;
+
+  my $args = $class->$orig(@arg);
+  my %copy = %{ $args };
 
   my $zilla = delete $copy{zilla};
   my $name  = delete $copy{plugin_name};
@@ -142,6 +145,7 @@ sub BUILDARGS {
 
   # Handle magic plugin names:
   unless (($other{phase} and $other{type})
+            # plugin comes from a bundle
           or $name =~ m! (?: \A | / ) Prereqs? \z !x) {
 
     my ($phase, $type) = $name =~ /\A
@@ -165,7 +169,7 @@ sub BUILDARGS {
     _prereq     => \%copy,
     %other,
   }
-}
+};
 
 sub register_prereqs {
   my ($self) = @_;
@@ -212,7 +216,7 @@ Dist::Zilla::Plugin::Prereqs - list simple prerequisites
 
 =head1 VERSION
 
-version 5.020
+version 5.043
 
 =head1 SYNOPSIS
 
@@ -343,7 +347,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
