@@ -1,12 +1,10 @@
 package Dist::Zilla::Plugin::ShareDir;
 # ABSTRACT: install a directory's contents as "ShareDir" content
-$Dist::Zilla::Plugin::ShareDir::VERSION = '5.020';
+$Dist::Zilla::Plugin::ShareDir::VERSION = '5.043';
 use Moose;
 
 use namespace::autoclean;
 
-use Moose::Autobox;
-
 #pod =head1 SYNOPSIS
 #pod
 #pod In your F<dist.ini>:
@@ -14,7 +12,7 @@ use Moose::Autobox;
 #pod   [ShareDir]
 #pod   dir = share
 #pod
-#pod   If no C<dir> is provided, the default is F<share>.
+#pod If no C<dir> is provided, the default is F<share>.
 #pod
 #pod =cut
 
@@ -28,7 +26,10 @@ sub find_files {
   my ($self) = @_;
 
   my $dir = $self->dir;
-  my $files = $self->zilla->files->grep(sub { index($_->name, "$dir/") == 0 });
+  my $files = [
+    grep { index($_->name, "$dir/") == 0 }
+      @{ $self->zilla->files }
+  ];
 }
 
 sub share_dir_map {
@@ -55,7 +56,7 @@ Dist::Zilla::Plugin::ShareDir - install a directory's contents as "ShareDir" con
 
 =head1 VERSION
 
-version 5.020
+version 5.043
 
 =head1 SYNOPSIS
 
@@ -64,7 +65,7 @@ In your F<dist.ini>:
   [ShareDir]
   dir = share
 
-  If no C<dir> is provided, the default is F<share>.
+If no C<dir> is provided, the default is F<share>.
 
 =head1 AUTHOR
 
@@ -72,7 +73,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
