@@ -1,12 +1,12 @@
 package Dist::Zilla::PluginBundle::Filter;
 # ABSTRACT: use another bundle, with some plugins removed
-$Dist::Zilla::PluginBundle::Filter::VERSION = '5.020';
+$Dist::Zilla::PluginBundle::Filter::VERSION = '5.043';
 use Moose;
-use Moose::Autobox;
 with 'Dist::Zilla::Role::PluginBundle';
 
 use namespace::autoclean;
 
+use List::Util 1.33 qw(any);
 use Class::Load qw(try_load_class);
 use Dist::Zilla::Util;
 
@@ -16,6 +16,7 @@ use Dist::Zilla::Util;
 #pod
 #pod   [@Filter]
 #pod   -bundle = @Basic
+#pod   -version = 5.031
 #pod   -remove = ShareDir
 #pod   -remove = UploadToCPAN
 #pod   option = for_basic
@@ -26,8 +27,14 @@ use Dist::Zilla::Util;
 #pod includes all the configuration for the bundle named in the C<-bundle> attribute,
 #pod but removes all the entries whose package is given in the C<-remove> attributes.
 #pod
+#pod A minimum required version of the bundle can be specified with the C<-version> 
+#pod attribute.
+#pod
 #pod Options not prefixed with C<-> will be passed to the bundle to be filtered.
 #pod
+#pod B<NOTE:> When you filter a bundle you B<SHOULD NOT> include it directly in
+#pod your C<dist.ini> file. This plugin will take care of including it for you.
+#pod
 #pod =head1 SEE ALSO
 #pod
 #pod Core Dist::Zilla plugins: L<@Basic|Dist::Zilla::PluginBundle::Basic>.
@@ -44,8 +51,8 @@ sub bundle_config {
 
   my $config = {};
 
-  my $has_filter_args = $section->{payload}->keys->grep(sub { /^-/ })->length;
-  for my $key ($section->{payload}->keys->flatten) {
+  my $has_filter_args = any { /^-/ } keys %{ $section->{payload} };
+  for my $key (keys %{ $section->{payload} }) {
     my $val = $section->{payload}->{$key};
     my $target = $has_filter_args && ($key !~ /^-/)
       ? 'bundle'
@@ -102,7 +109,7 @@ Dist::Zilla::PluginBundle::Filter - use another bundle, with some plugins remove
 
 =head1 VERSION
 
-version 5.020
+version 5.043
 
 =head1 SYNOPSIS
 
@@ -110,6 +117,7 @@ In your F<dist.ini>:
 
   [@Filter]
   -bundle = @Basic
+  -version = 5.031
   -remove = ShareDir
   -remove = UploadToCPAN
   option = for_basic
@@ -120,8 +128,14 @@ This plugin bundle actually wraps and modifies another plugin bundle.  It
 includes all the configuration for the bundle named in the C<-bundle> attribute,
 but removes all the entries whose package is given in the C<-remove> attributes.
 
+A minimum required version of the bundle can be specified with the C<-version> 
+attribute.
+
 Options not prefixed with C<-> will be passed to the bundle to be filtered.
 
+B<NOTE:> When you filter a bundle you B<SHOULD NOT> include it directly in
+your C<dist.ini> file. This plugin will take care of including it for you.
+
 =head1 SEE ALSO
 
 Core Dist::Zilla plugins: L<@Basic|Dist::Zilla::PluginBundle::Basic>.
@@ -134,7 +148,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
