@@ -1,8 +1,7 @@
 package Dist::Zilla::Prereqs;
 # ABSTRACT: the prerequisites of a Dist::Zilla distribution
-$Dist::Zilla::Prereqs::VERSION = '5.020';
+$Dist::Zilla::Prereqs::VERSION = '5.043';
 use Moose;
-use Moose::Autobox;
 use MooseX::Types::Moose qw(Bool HashRef);
 
 use CPAN::Meta::Prereqs 2.120630; # add_string_requirement
@@ -50,6 +49,8 @@ has cpan_meta_prereqs => (
 
 # storing this is sort of gross, but MakeMaker winds up needing the same data
 # anyway. -- xdg, 2013-10-22
+# This does *not* contain configure requires, as MakeMaker explicitly should
+# not have it in its fallback prereqs.
 has merged_requires => (
   is => 'ro',
   isa => 'CPAN::Meta::Requirements',
@@ -142,7 +143,7 @@ Dist::Zilla::Prereqs - the prerequisites of a Dist::Zilla distribution
 
 =head1 VERSION
 
-version 5.020
+version 5.043
 
 =head1 DESCRIPTION
 
@@ -206,7 +207,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
