@@ -1,15 +1,22 @@
 package Dist::Zilla::Role::FileGatherer;
-{
-  $Dist::Zilla::Role::FileGatherer::VERSION = '5.008';
-}
 # ABSTRACT: something that gathers files into the distribution
+$Dist::Zilla::Role::FileGatherer::VERSION = '5.043';
 use Moose::Role;
 with qw/Dist::Zilla::Role::Plugin Dist::Zilla::Role::FileInjector/;
 
 use namespace::autoclean;
 
-use Moose::Autobox;
-
+#pod =head1 DESCRIPTION
+#pod
+#pod A FileGatherer plugin is a special sort of
+#pod L<FileInjector|Dist::Zilla::Role::FileInjector> that runs early in the build
+#pod cycle, finding files to include in the distribution.  It is expected to call
+#pod its C<add_file> method to add one or more files to inclusion.
+#pod
+#pod Plugins implementing FileGatherer must provide a C<gather_files> method, which
+#pod will be called during the build process.
+#pod
+#pod =cut
 
 requires 'gather_files';
 
@@ -27,7 +34,7 @@ Dist::Zilla::Role::FileGatherer - something that gathers files into the distribu
 
 =head1 VERSION
 
-version 5.008
+version 5.043
 
 =head1 DESCRIPTION
 
@@ -45,7 +52,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
