@@ -1,26 +1,35 @@
 package Dist::Zilla::Role::FileInjector;
-{
-  $Dist::Zilla::Role::FileInjector::VERSION = '4.300030';
-}
 # ABSTRACT: something that can add files to the distribution
+$Dist::Zilla::Role::FileInjector::VERSION = '5.043';
 use Moose::Role;
 
 use namespace::autoclean;
 
-use Moose::Autobox;
-
+#pod =head1 DESCRIPTION
+#pod
+#pod This role should be implemented by any plugin that plans to add files into the
+#pod distribution.  It provides one method (C<L</add_file>>, documented below),
+#pod which adds a file to the distribution, noting the place of addition.
+#pod
+#pod =method add_file
+#pod
+#pod   $plugin->add_file($dzil_file);
+#pod
+#pod This adds a file to the distribution, setting the file's C<added_by> attribute
+#pod as it does so.
+#pod
+#pod =cut
 
 sub add_file {
   my ($self, $file) = @_;
   my ($pkg, undef, $line) = caller;
 
-  $file->meta->get_attribute('added_by')->set_value(
-    $file,
+  $file->_set_added_by(
     sprintf("%s (%s line %s)", $self->plugin_name, $pkg, $line),
   );
 
   $self->log_debug([ 'adding file %s', $file->name ]);
-  $self->zilla->files->push($file);
+  push @{ $self->zilla->files }, $file;
 }
 
 1;
@@ -29,13 +38,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Role::FileInjector - something that can add files to the distribution
 
 =head1 VERSION
 
-version 4.300030
+version 5.043
 
 =head1 DESCRIPTION
 
@@ -58,7 +69,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
