@@ -1,18 +1,13 @@
 package Dist::Zilla::Role::PPI;
 # ABSTRACT: a role for plugins which use PPI
-$Dist::Zilla::Role::PPI::VERSION = '5.020';
+$Dist::Zilla::Role::PPI::VERSION = '5.043';
 use Moose::Role;
-
-use Moose::Util::TypeConstraints;
-
-use namespace::autoclean;
-
 use Digest::MD5 qw(md5);
-use Storable qw(dclone);
+use namespace::autoclean;
 
 #pod =head1 DESCRIPTION
 #pod
-#pod This role provides some common utilities for plugins which use PPI
+#pod This role provides some common utilities for plugins which use L<PPI>.
 #pod
 #pod =method ppi_document_for_file
 #pod
@@ -34,13 +29,13 @@ sub ppi_document_for_file {
   my $encoded_content = $file->encoded_content;
 
   # We cache on the MD5 checksum to detect if the document has been modified
-  # by some other plugin since it was last parsed, our document is invalid.
+  # by some other plugin since it was last parsed, making our document invalid.
   my $md5 = md5($encoded_content);
   return $CACHE{$md5}->clone if $CACHE{$md5};
 
   require PPI::Document;
   my $document = PPI::Document->new(\$encoded_content)
-    or Carp::croak(PPI::Document->errstr);
+    or Carp::croak(PPI::Document->errstr . ' while processing file ' . $file->name);
 
   return ($CACHE{$md5} = $document)->clone;
 }
@@ -71,30 +66,41 @@ sub save_ppi_document_to_file {
 #pod
 #pod   if( $self->ppi_document_for_file($document, '$FOO')) { ... }
 #pod
-#pod This method returns true if the document assigns to the given variable.
+#pod This method returns true if the document assigns to the given variable (the
+#pod sigil must be included).
 #pod
 #pod =cut
 
 sub document_assigns_to_variable {
-  my ($self, $orig_document, $variable) = @_;
+  my ($self, $document, $variable) = @_;
 
-  # Clone because ppi_document_for_file which the caller is likely to
-  # have retrieved his document from caches aggressively, and we'd
-  # like to prun POD and comments.
-  #
-  # It would be pretty stupid of us to say we found a variable in some
-  # comment or in the POD, which we might do because if the POD is
-  # preceded by __END__ or __DATA__ it'll be a PPI::Statement. So
-  # prune PPI::Statement::* things that we don't want, note that we
-  # don't have to prune e.g. PPI::Token::Pod because of the isa check
-  # in the finder below.
-  my $document = dclone($orig_document);
-  $document->prune($_) for qw(PPI::Statement::End PPI::Statement::Data);
+  my $package_stmts = $document->find('PPI::Statement::Package');
+  my @namespaces = map { $_->namespace } @{ $package_stmts || []};
 
+  my ($sigil, $varname) = ($variable =~ m'^([$@%*])(.+)$');
+
+  my $package;
   my $finder = sub {
     my $node = $_[1];
-    return 1 if $node->isa('PPI::Statement') && $node->content =~ /(?<!\\)\Q$variable\E\s*=/sm;
-    return 0;
+
+    if ($node->isa('PPI::Statement')
+      && !$node->isa('PPI::Statement::End')
+      && !$node->isa('PPI::Statement::Data')) {
+
+      if ($node->isa('PPI::Statement::Variable')) {
+        return (grep { $_ eq $variable } $node->variables) ? 1 : undef;
+      }
+
+      return 1 if grep {
+        my $child = $_;
+        $child->isa('PPI::Token::Symbol')
+          and grep {
+            $child->canonical eq "${sigil}${_}::${varname}"
+                and $node->content =~ /\Q${sigil}${_}::${varname}\E.*=/
+          } @namespaces
+      } $node->children;
+    }
+    return 0;   # not found
   };
 
   my $rv = $document->find_any($finder);
@@ -117,11 +123,11 @@ Dist::Zilla::Role::PPI - a role for plugins which use PPI
 
 =head1 VERSION
 
-version 5.020
+version 5.043
 
 =head1 DESCRIPTION
 
-This role provides some common utilities for plugins which use PPI
+This role provides some common utilities for plugins which use L<PPI>.
 
 =head1 METHODS
 
@@ -149,7 +155,8 @@ It also updates the internal PPI document cache with the new document.
 
   if( $self->ppi_document_for_file($document, '$FOO')) { ... }
 
-This method returns true if the document assigns to the given variable.
+This method returns true if the document assigns to the given variable (the
+sigil must be included).
 
 =head1 AUTHOR
 
@@ -157,7 +164,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
