@@ -2,9 +2,9 @@ use strict;
 use warnings;
 package Dist::Zilla::Util::AuthorDeps;
 # ABSTRACT: Utils for listing your distribution's author dependencies
-$Dist::Zilla::Util::AuthorDeps::VERSION = '5.020';
+$Dist::Zilla::Util::AuthorDeps::VERSION = '5.043';
 use Dist::Zilla::Util;
-use Path::Class;
+use Path::Tiny;
 use List::MoreUtils ();
 
 
@@ -23,13 +23,12 @@ sub format_author_deps {
 sub extract_author_deps {
   my ($root, $missing) = @_;
 
-  my $ini = $root->file('dist.ini');
+  my $ini = path($root, 'dist.ini');
 
   die "dzil authordeps only works on dist.ini files, and you don't have one\n"
     unless -e $ini;
 
-  my $fh = $ini->openr;
-  binmode($fh, ":encoding(UTF-8)");
+  my $fh = $ini->openr_utf8;
 
   require Config::INI::Reader;
   my $config = Config::INI::Reader->read_handle($fh);
@@ -37,17 +36,19 @@ sub extract_author_deps {
   require CPAN::Meta::Requirements;
   my $reqs = CPAN::Meta::Requirements->new;
 
-  my @packs =
-    map  { s/\s.*//; $_ }
-    grep { $_ ne '_' }
-    keys %$config;
+  if (defined (my $license = $config->{_}->{license})) {
+    $license = 'Software::License::'.$license;
+    $reqs->add_minimum($license => 0);
+  }
 
-  foreach my $pack (@packs) {
+  for my $section ( sort keys %$config ) {
+    next if q[_] eq $section;
+    my $pack = $section;
+    $pack =~ s{\s*/.*$}{}; # trim optional space and slash-delimited suffix
 
     my $version = 0;
-    if(exists $config->{$pack} && exists $config->{$pack}->{':version'}) {
-      $version = $config->{$pack}->{':version'};
-    }
+    $version = $config->{$section}->{':version'} if exists $config->{$section}->{':version'};
+
     my $realname = Dist::Zilla::Util->expand_config_package_name($pack);
     $reqs->add_minimum($realname => $version);
   }
@@ -71,14 +72,14 @@ sub extract_author_deps {
   my @packages;
   while (<$fh>) {
     chomp;
-    next unless /\A\s*;\s*authordep\s*(\S+)\s*(=\s*(\S+))?\s*\z/;
-    my $ver = defined $3 ? $3 : "0";
+    next unless /\A\s*;\s*authordep\s*(\S+)\s*(?:=\s*(.+))?\s*\z/;
+    my $ver = defined $2 ? $2 : "0";
     # Any "; authordep " is inserted at the beginning of the list
     # in the file order so the user can control the order of at least a part of
     # the plugin list
     push @packages, $1;
     # And added to the requirements so we can use it later
-    $reqs->add_minimum($1 => $ver);
+    $reqs->add_string_requirement($1 => $ver);
   }
 
   my $vermap = $reqs->as_string_hash;
@@ -128,7 +129,7 @@ Dist::Zilla::Util::AuthorDeps - Utils for listing your distribution's author dep
 
 =head1 VERSION
 
-version 5.020
+version 5.043
 
 =head1 AUTHOR
 
@@ -136,7 +137,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
