@@ -2,10 +2,10 @@ use strict;
 use warnings;
 package Test::DZil;
 # ABSTRACT: tools for testing Dist::Zilla plugins
-$Test::DZil::VERSION = '5.020';
+$Test::DZil::VERSION = '5.043';
 use Dist::Zilla::Tester;
 use Params::Util qw(_HASH0);
-use JSON 2;
+use JSON::MaybeXS;
 use Scalar::Util qw(blessed);
 use Test::Deep ();
 use YAML::Tiny;
@@ -52,15 +52,15 @@ use Sub::Exporter -setup => {
 sub is_filelist {
   my ($have, $want, $comment) = @_;
 
-  my @want = sort @$want;
-  my @have = sort map { my $str = (blessed $_ and
-                                   $_->DOES('Dist::Zilla::Role::File'))
-                            ? $_->name
-                            : $_;
-                        $str =~ s{\\}{/}g; $str } @$have;
+  my @want = @$want;
+  my @have = map { my $str = (blessed $_ and
+                              $_->DOES('Dist::Zilla::Role::File'))
+                       ? $_->name
+                       : $_;
+                   $str =~ s{\\}{/}g; $str } @$have;
 
   local $Test::Builder::Level = $Test::Builder::Level + 1;
-  Test::More::is_deeply(\@have, \@want, $comment);
+  Test::Deep::cmp_bag(\@have, \@want, $comment);
 }
 
 #pod =func is_yaml
@@ -94,7 +94,7 @@ sub is_yaml {
 sub is_json {
   my ($json, $want, $comment) = @_;
 
-  my $have = JSON->new->ascii(1)->decode($json)
+  my $have = JSON::MaybeXS->new(ascii => 1)->decode($json)
     or die "Cannot decode JSON";
 
   local $Test::Builder::Level = $Test::Builder::Level + 1;
@@ -113,7 +113,7 @@ sub _build_ini_builder {
 
     my $config = '';
 
-    for my $key (keys %$core_config) {
+    for my $key (sort keys %$core_config) {
       my @values = ref $core_config->{ $key }
                  ? @{ $core_config->{ $key } }
                  : $core_config->{ $key };
@@ -135,7 +135,7 @@ sub _build_ini_builder {
       $config .= ' / ' . $name if defined $name;
       $config .= "]\n";
 
-      for my $key (keys %$payload) {
+      for my $key (sort keys %$payload) {
         my @values = ref $payload->{ $key }
                    ? @{ $payload->{ $key } }
                    : $payload->{ $key };
@@ -240,7 +240,7 @@ Test::DZil - tools for testing Dist::Zilla plugins
 
 =head1 VERSION
 
-version 5.020
+version 5.043
 
 =head1 DESCRIPTION
 
@@ -343,7 +343,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
